#define MOZ_SOURCE_STAMP 05853bb06a8739b77c2937f418cdf4e1610d0d9f
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-beta
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-beta/rev/05853bb06a8739b77c2937f418cdf4e1610d0d9f
